@@ -468,7 +468,7 @@ $catalogue = new MessageCatalogue('en', array (
     'shopware.installer.database-configuration_fetch_error' => 'An error occurred while fetching the database information',
     'shopware.installer.database-configuration_access_denied' => 'Access denied, credentials are incorrect',
     'shopware.installer.database-configuration_host_not_found' => 'Could not connect to database server',
-    'shopware.installer.database-configuration_invalid_requirements' => 'Shopware 6 requires at least MySQL 5.7.21 or MariaDB 10.3.22',
+    'shopware.installer.database-configuration_invalid_requirements' => 'Shopware 6 requires at least MySQL 8.0.17 or MariaDB 10.11',
     'shopware.installer.database-configuration_refresh_databases' => 'Refresh Databases',
     'shopware.installer.database-import_header' => 'Installation',
     'shopware.installer.database-import_skip_import' => 'Skip',
